==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/containerinstance/kotlin/inputs/InitContainerDefinitionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerinstance.kotlin.inputs

import com.pulumi.azurenative.containerinstance.inputs.InitContainerDefinitionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The init container definition.
 * @property command The command to execute within the init container in exec form.
 * @property environmentVariables The environment variables to set in the init container.
 * @property image The image of the init container.
 * @property name The name for the init container.
 * @property securityContext The container security properties.
 * @property volumeMounts The volume mounts available to the init container.
 */
public data class InitContainerDefinitionArgs(
    public val command: Output<List<String>>? = null,
    public val environmentVariables: Output<List<EnvironmentVariableArgs>>? = null,
    public val image: Output<String>? = null,
    public val name: Output<String>,
    public val securityContext: Output<SecurityContextDefinitionArgs>? = null,
    public val volumeMounts: Output<List<VolumeMountArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.containerinstance.inputs.InitContainerDefinitionArgs> {
    override fun toJava(): com.pulumi.azurenative.containerinstance.inputs.InitContainerDefinitionArgs =
        com.pulumi.azurenative.containerinstance.inputs.InitContainerDefinitionArgs.builder()
            .command(command?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .environmentVariables(
                environmentVariables?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .image(image?.applyValue({ args0 -> args0 }))
            .name(name.applyValue({ args0 -> args0 }))
            .securityContext(securityContext?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .volumeMounts(
                volumeMounts?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [InitContainerDefinitionArgs].
 */
@PulumiTagMarker
public class InitContainerDefinitionArgsBuilder internal constructor() {
    private var command: Output<List<String>>? = null

    private var environmentVariables: Output<List<EnvironmentVariableArgs>>? = null

    private var image: Output<String>? = null

    private var name: Output<String>? = null

    private var securityContext: Output<SecurityContextDefinitionArgs>? = null

    private var volumeMounts: Output<List<VolumeMountArgs>>? = null

    /**
     * @param value The command to execute within the init container in exec form.
     */
    @JvmName("cuyqdmetqsvhahyv")
    public suspend fun command(`value`: Output<List<String>>) {
        this.command = value
    }

    @JvmName("otxfioxkhaughoba")
    public suspend fun command(vararg values: Output<String>) {
        this.command = Output.all(values.asList())
    }

    /**
     * @param values The command to execute within the init container in exec form.
     */
    @JvmName("cvjmvtsfelnnchgb")
    public suspend fun command(values: List<Output<String>>) {
        this.command = Output.all(values)
    }

    /**
     * @param value The environment variables to set in the init container.
     */
    @JvmName("inetjgxljbsscsgj")
    public suspend fun environmentVariables(`value`: Output<List<EnvironmentVariableArgs>>) {
        this.environmentVariables = value
    }

    @JvmName("wcuuidnitpdasupb")
    public suspend fun environmentVariables(vararg values: Output<EnvironmentVariableArgs>) {
        this.environmentVariables = Output.all(values.asList())
    }

    /**
     * @param values The environment variables to set in the init container.
     */
    @JvmName("gibjlwimetkvgwsi")
    public suspend fun environmentVariables(values: List<Output<EnvironmentVariableArgs>>) {
        this.environmentVariables = Output.all(values)
    }

    /**
     * @param value The image of the init container.
     */
    @JvmName("ihqjnvpyuypwwikg")
    public suspend fun image(`value`: Output<String>) {
        this.image = value
    }

    /**
     * @param value The name for the init container.
     */
    @JvmName("dqqbrvbdlwlbcisp")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The container security properties.
     */
    @JvmName("gsjvgvhywkbanyfh")
    public suspend fun securityContext(`value`: Output<SecurityContextDefinitionArgs>) {
        this.securityContext = value
    }

    /**
     * @param value The volume mounts available to the init container.
     */
    @JvmName("lbcedchxunglahlx")
    public suspend fun volumeMounts(`value`: Output<List<VolumeMountArgs>>) {
        this.volumeMounts = value
    }

    @JvmName("dfblhxeaglijhwqb")
    public suspend fun volumeMounts(vararg values: Output<VolumeMountArgs>) {
        this.volumeMounts = Output.all(values.asList())
    }

    /**
     * @param values The volume mounts available to the init container.
     */
    @JvmName("oagoxlsmhvoksbsm")
    public suspend fun volumeMounts(values: List<Output<VolumeMountArgs>>) {
        this.volumeMounts = Output.all(values)
    }

    /**
     * @param value The command to execute within the init container in exec form.
     */
    @JvmName("welbayilwsertncv")
    public suspend fun command(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.command = mapped
    }

    /**
     * @param values The command to execute within the init container in exec form.
     */
    @JvmName("gyrfqfauphptpnfa")
    public suspend fun command(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.command = mapped
    }

    /**
     * @param value The environment variables to set in the init container.
     */
    @JvmName("ugtbpyvgkfsinoaa")
    public suspend fun environmentVariables(`value`: List<EnvironmentVariableArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.environmentVariables = mapped
    }

    /**
     * @param argument The environment variables to set in the init container.
     */
    @JvmName("pbmdbwgtspppweoy")
    public suspend
    fun environmentVariables(argument: List<suspend EnvironmentVariableArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            EnvironmentVariableArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.environmentVariables = mapped
    }

    /**
     * @param argument The environment variables to set in the init container.
     */
    @JvmName("ylnalxeciojpbsqp")
    public suspend fun environmentVariables(
        vararg
        argument: suspend EnvironmentVariableArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            EnvironmentVariableArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.environmentVariables = mapped
    }

    /**
     * @param argument The environment variables to set in the init container.
     */
    @JvmName("ngaecisbpbmcphbs")
    public suspend
    fun environmentVariables(argument: suspend EnvironmentVariableArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(EnvironmentVariableArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.environmentVariables = mapped
    }

    /**
     * @param values The environment variables to set in the init container.
     */
    @JvmName("sabcxonlofblxiot")
    public suspend fun environmentVariables(vararg values: EnvironmentVariableArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.environmentVariables = mapped
    }

    /**
     * @param value The image of the init container.
     */
    @JvmName("sfnjdefcoxthkrjc")
    public suspend fun image(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.image = mapped
    }

    /**
     * @param value The name for the init container.
     */
    @JvmName("ariuftnsvblccjqo")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The container security properties.
     */
    @JvmName("ernhtysjmsuvykdu")
    public suspend fun securityContext(`value`: SecurityContextDefinitionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.securityContext = mapped
    }

    /**
     * @param argument The container security properties.
     */
    @JvmName("cjqvqxyiibqloppv")
    public suspend
    fun securityContext(argument: suspend SecurityContextDefinitionArgsBuilder.() -> Unit) {
        val toBeMapped = SecurityContextDefinitionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.securityContext = mapped
    }

    /**
     * @param value The volume mounts available to the init container.
     */
    @JvmName("qupvidybwiibgamp")
    public suspend fun volumeMounts(`value`: List<VolumeMountArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.volumeMounts = mapped
    }

    /**
     * @param argument The volume mounts available to the init container.
     */
    @JvmName("imbjingfcoiyrudq")
    public suspend fun volumeMounts(argument: List<suspend VolumeMountArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { VolumeMountArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.volumeMounts = mapped
    }

    /**
     * @param argument The volume mounts available to the init container.
     */
    @JvmName("tggriedippohvdqt")
    public suspend fun volumeMounts(vararg argument: suspend VolumeMountArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { VolumeMountArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.volumeMounts = mapped
    }

    /**
     * @param argument The volume mounts available to the init container.
     */
    @JvmName("mddvoxygkieirfya")
    public suspend fun volumeMounts(argument: suspend VolumeMountArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(VolumeMountArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.volumeMounts = mapped
    }

    /**
     * @param values The volume mounts available to the init container.
     */
    @JvmName("goieljnjfcodikjr")
    public suspend fun volumeMounts(vararg values: VolumeMountArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.volumeMounts = mapped
    }

    internal fun build(): InitContainerDefinitionArgs = InitContainerDefinitionArgs(
        command = command,
        environmentVariables = environmentVariables,
        image = image,
        name = name ?: throw PulumiNullFieldException("name"),
        securityContext = securityContext,
        volumeMounts = volumeMounts,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/containerinstance/kotlin/inputs/InitContainerDefinitionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerinstance.kotlin.inputs

import com.pulumi.azurenative.containerinstance.inputs.InitContainerDefinitionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The init container definition.
 * @property command The command to execute within the init container in exec form.
 * @property environmentVariables The environment variables to set in the init container.
 * @property image The image of the init container.
 * @property name The name for the init container.
 * @property securityContext The container security properties.
 * @property volumeMounts The volume mounts available to the init container.
 */
public data class InitContainerDefinitionArgs(
    public val command: Output<List<String>>? = null,
    public val environmentVariables: Output<List<EnvironmentVariableArgs>>? = null,
    public val image: Output<String>? = null,
    public val name: Output<String>,
    public val securityContext: Output<SecurityContextDefinitionArgs>? = null,
    public val volumeMounts: Output<List<VolumeMountArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.containerinstance.inputs.InitContainerDefinitionArgs> {
    override fun toJava(): com.pulumi.azurenative.containerinstance.inputs.InitContainerDefinitionArgs =
        com.pulumi.azurenative.containerinstance.inputs.InitContainerDefinitionArgs.builder()
            .command(command?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .environmentVariables(
                environmentVariables?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .image(image?.applyValue({ args0 -> args0 }))
            .name(name.applyValue({ args0 -> args0 }))
            .securityContext(securityContext?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .volumeMounts(
                volumeMounts?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [InitContainerDefinitionArgs].
 */
@PulumiTagMarker
public class InitContainerDefinitionArgsBuilder internal constructor() {
    private var command: Output<List<String>>? = null

    private var environmentVariables: Output<List<EnvironmentVariableArgs>>? = null

    private var image: Output<String>? = null

    private var name: Output<String>? = null

    private var securityContext: Output<SecurityContextDefinitionArgs>? = null

    private var volumeMounts: Output<List<VolumeMountArgs>>? = null

    /**
     * @param value The command to execute within the init container in exec form.
     */
    @JvmName("lgwpdnylyeogrshm")
    public suspend fun command(`value`: Output<List<String>>) {
        this.command = value
    }

    @JvmName("pcxdtdbhnegyiqlt")
    public suspend fun command(vararg values: Output<String>) {
        this.command = Output.all(values.asList())
    }

    /**
     * @param values The command to execute within the init container in exec form.
     */
    @JvmName("jksaxxgcohjldfpm")
    public suspend fun command(values: List<Output<String>>) {
        this.command = Output.all(values)
    }

    /**
     * @param value The environment variables to set in the init container.
     */
    @JvmName("oowxvjbupuubfquo")
    public suspend fun environmentVariables(`value`: Output<List<EnvironmentVariableArgs>>) {
        this.environmentVariables = value
    }

    @JvmName("ngkvulfgvhliggjy")
    public suspend fun environmentVariables(vararg values: Output<EnvironmentVariableArgs>) {
        this.environmentVariables = Output.all(values.asList())
    }

    /**
     * @param values The environment variables to set in the init container.
     */
    @JvmName("vctqkdmxfvtatjou")
    public suspend fun environmentVariables(values: List<Output<EnvironmentVariableArgs>>) {
        this.environmentVariables = Output.all(values)
    }

    /**
     * @param value The image of the init container.
     */
    @JvmName("idafdbbueypphgjc")
    public suspend fun image(`value`: Output<String>) {
        this.image = value
    }

    /**
     * @param value The name for the init container.
     */
    @JvmName("hbhpekrkqkoffpyq")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The container security properties.
     */
    @JvmName("hxggvkrnksimksnu")
    public suspend fun securityContext(`value`: Output<SecurityContextDefinitionArgs>) {
        this.securityContext = value
    }

    /**
     * @param value The volume mounts available to the init container.
     */
    @JvmName("tcoffmtwjnvlsjwm")
    public suspend fun volumeMounts(`value`: Output<List<VolumeMountArgs>>) {
        this.volumeMounts = value
    }

    @JvmName("bljcyujaembdioru")
    public suspend fun volumeMounts(vararg values: Output<VolumeMountArgs>) {
        this.volumeMounts = Output.all(values.asList())
    }

    /**
     * @param values The volume mounts available to the init container.
     */
    @JvmName("euegkeabntbeelxt")
    public suspend fun volumeMounts(values: List<Output<VolumeMountArgs>>) {
        this.volumeMounts = Output.all(values)
    }

    /**
     * @param value The command to execute within the init container in exec form.
     */
    @JvmName("nkbuvryvsgsfcjaw")
    public suspend fun command(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.command = mapped
    }

    /**
     * @param values The command to execute within the init container in exec form.
     */
    @JvmName("nlrhjiewebjinjtm")
    public suspend fun command(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.command = mapped
    }

    /**
     * @param value The environment variables to set in the init container.
     */
    @JvmName("lmtowgpmgluvhkwl")
    public suspend fun environmentVariables(`value`: List<EnvironmentVariableArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.environmentVariables = mapped
    }

    /**
     * @param argument The environment variables to set in the init container.
     */
    @JvmName("rjswpitwmclsegio")
    public suspend
    fun environmentVariables(argument: List<suspend EnvironmentVariableArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            EnvironmentVariableArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.environmentVariables = mapped
    }

    /**
     * @param argument The environment variables to set in the init container.
     */
    @JvmName("kbgmsviciytduujy")
    public suspend fun environmentVariables(
        vararg
        argument: suspend EnvironmentVariableArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            EnvironmentVariableArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.environmentVariables = mapped
    }

    /**
     * @param argument The environment variables to set in the init container.
     */
    @JvmName("iexhlggktxqxovvo")
    public suspend
    fun environmentVariables(argument: suspend EnvironmentVariableArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(EnvironmentVariableArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.environmentVariables = mapped
    }

    /**
     * @param values The environment variables to set in the init container.
     */
    @JvmName("ptqscfboxluejjtf")
    public suspend fun environmentVariables(vararg values: EnvironmentVariableArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.environmentVariables = mapped
    }

    /**
     * @param value The image of the init container.
     */
    @JvmName("kagenfijuxelxlvu")
    public suspend fun image(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.image = mapped
    }

    /**
     * @param value The name for the init container.
     */
    @JvmName("vheetjkbnctpqiua")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The container security properties.
     */
    @JvmName("vtyulxpwbqpncocb")
    public suspend fun securityContext(`value`: SecurityContextDefinitionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.securityContext = mapped
    }

    /**
     * @param argument The container security properties.
     */
    @JvmName("daijohpaomlgkmoc")
    public suspend
    fun securityContext(argument: suspend SecurityContextDefinitionArgsBuilder.() -> Unit) {
        val toBeMapped = SecurityContextDefinitionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.securityContext = mapped
    }

    /**
     * @param value The volume mounts available to the init container.
     */
    @JvmName("khfignhqqhgodaui")
    public suspend fun volumeMounts(`value`: List<VolumeMountArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.volumeMounts = mapped
    }

    /**
     * @param argument The volume mounts available to the init container.
     */
    @JvmName("lueltdigwujndgqv")
    public suspend fun volumeMounts(argument: List<suspend VolumeMountArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { VolumeMountArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.volumeMounts = mapped
    }

    /**
     * @param argument The volume mounts available to the init container.
     */
    @JvmName("pdysbchgpxoakmee")
    public suspend fun volumeMounts(vararg argument: suspend VolumeMountArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { VolumeMountArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.volumeMounts = mapped
    }

    /**
     * @param argument The volume mounts available to the init container.
     */
    @JvmName("qfcgjbinecpfcpbo")
    public suspend fun volumeMounts(argument: suspend VolumeMountArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(VolumeMountArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.volumeMounts = mapped
    }

    /**
     * @param values The volume mounts available to the init container.
     */
    @JvmName("qsuwmddikkbvwsha")
    public suspend fun volumeMounts(vararg values: VolumeMountArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.volumeMounts = mapped
    }

    internal fun build(): InitContainerDefinitionArgs = InitContainerDefinitionArgs(
        command = command,
        environmentVariables = environmentVariables,
        image = image,
        name = name ?: throw PulumiNullFieldException("name"),
        securityContext = securityContext,
        volumeMounts = volumeMounts,
    )
}
